<?php

class gmb_post_factory
{
    public static function create()
    {
        $selection = rand(1, 4);

        // 3/4ths chance of creating a rental post
        if ($selection < 4) return new individual_product_post();
        else return new category_product_post();
    }
}

interface gmb_post_factory_base
{
    public function createPost($data);
}

class individual_product_post implements gmb_post_factory_base
{
    public function createPost($data)
    {
        $action_type = rand(0, 1) == 0 ? "BOOK" : "ORDER";

        return [
            'languageCode' => 'en-US',
            'summary' => $data["rental_name"]. ' - ' .$data["rental_description"],
            'callToAction' => [
                'actionType' => $action_type,
                'url' => $data["rental_url"],
            ],
            'media' => [
                'sourceUrl' => $data["rental_image"],
                'mediaFormat' => 'PHOTO',
            ],
            'topicType' => 'STANDARD',
        ];
    }
}

class category_product_post implements gmb_post_factory_base
{
    public function createPost($data)
    {
        $action_type = rand(0, 1) == 0 ? "BOOK" : "ORDER";

        return [
            'languageCode' => 'en-US',
            'summary' => $data["category_name"]. ' - ' .$data["category_description"],
            'callToAction' => [
                'actionType' => $action_type,
                'url' => $data["category_url"],
            ],
            'media' => [
                'sourceUrl' => $data["category_image"],
                'mediaFormat' => 'PHOTO',
            ],
            'topicType' => 'STANDARD',
        ];
    }
}

class general_information_post implements gmb_post_factory_base
{
    /**
     * Takes in an array '$data' for passing the homepage URL in
     * @param $data
     * @return array
     */
    public function createPost($data)
    {

        return [
            'languageCode' => 'en-US',
            'summary' => 'Test summary',//todo: need to discuss how to import the data Shane's been using for the Summaries beyond that this will probably be populated by the item description or category description?
            'callToAction' => [
                'actionType' => 'LEARN_MORE',
                'url' => $data["website_url"],
            ],
            'media' => [
                'sourceUrl' => 'https://picsum.photos/800',//todo:
                'mediaFormat' => 'PHOTO',
            ],
            'topicType' => 'STANDARD',
        ];
    }
}